@@ -49,8 +49,10 @@ func (self *WorkingTreeCommands) StageFiles(paths []string, extraArgs []string)
 }
 
 // StageAll stages all files
-func (self *WorkingTreeCommands) StageAll() error {
-	cmdArgs := NewGitCmd("add").Arg("-A").ToArgv()
+func (self *WorkingTreeCommands) StageAll(onlyTrackedFiles bool) error {
+	cmdArgs := NewGitCmd("add").
+		ArgIfElse(onlyTrackedFiles, "-u", "-A").
+		ToArgv()
 
 	return self.cmd.New(cmdArgs).Run()
 }
@@ -66,9 +68,8 @@ func (self *WorkingTreeCommands) UnstageAll() error {
 func (self *WorkingTreeCommands) UnStageFile(paths []string, tracked bool) error {
 	if tracked {
 		return self.UnstageTrackedFiles(paths)
-	} else {
-		return self.UnstageUntrackedFiles(paths)
 	}
+	return self.UnstageUntrackedFiles(paths)
 }
 
 func (self *WorkingTreeCommands) UnstageTrackedFiles(paths []string) error {
@@ -261,7 +262,7 @@ func (self *WorkingTreeCommands) WorktreeFileDiffCmdObj(node models.IFile, plain
 		colorArg = "never"
 	}
 
-	contextSize := self.AppState.DiffContextSize
+	contextSize := self.UserConfig().Git.DiffContextSize
 	prevPath := node.GetPreviousPath()
 	noIndex := !node.GetIsTracked() && !node.GetHasStagedChanges() && !cached && node.GetIsFile()
 	extDiffCmd := self.UserConfig().Git.Paging.ExternalDiffCommand
@@ -273,8 +274,8 @@ func (self *WorkingTreeCommands) WorktreeFileDiffCmdObj(node models.IFile, plain
 		Arg("--submodule").
 		Arg(fmt.Sprintf("--unified=%d", contextSize)).
 		Arg(fmt.Sprintf("--color=%s", colorArg)).
-		ArgIf(!plain && self.AppState.IgnoreWhitespaceInDiffView, "--ignore-all-space").
-		Arg(fmt.Sprintf("--find-renames=%d%%", self.AppState.RenameSimilarityThreshold)).
+		ArgIf(!plain && self.UserConfig().Git.IgnoreWhitespaceInDiffView, "--ignore-all-space").
+		Arg(fmt.Sprintf("--find-renames=%d%%", self.UserConfig().Git.RenameSimilarityThreshold)).
 		ArgIf(cached, "--cached").
 		ArgIf(noIndex, "--no-index").
 		Arg("--").
@@ -294,7 +295,7 @@ func (self *WorkingTreeCommands) ShowFileDiff(from string, to string, reverse bo
 }
 
 func (self *WorkingTreeCommands) ShowFileDiffCmdObj(from string, to string, reverse bool, fileName string, plain bool) *oscommands.CmdObj {
-	contextSize := self.AppState.DiffContextSize
+	contextSize := self.UserConfig().Git.DiffContextSize
 
 	colorArg := self.UserConfig().Git.Paging.ColorArg
 	if plain {
@@ -315,7 +316,7 @@ func (self *WorkingTreeCommands) ShowFileDiffCmdObj(from string, to string, reve
 		Arg(from).
 		Arg(to).
 		ArgIf(reverse, "-R").
-		ArgIf(!plain && self.AppState.IgnoreWhitespaceInDiffView, "--ignore-all-space").
+		ArgIf(!plain && self.UserConfig().Git.IgnoreWhitespaceInDiffView, "--ignore-all-space").
 		Arg("--").
 		Arg(fileName).
 		Dir(self.repoPaths.worktreePath).
