@@ -13,7 +13,6 @@ import (
 	"github.com/samber/lo"
 
 	"github.com/atotto/clipboard"
-	"github.com/jesseduffield/kill"
 	"github.com/jesseduffield/lazygit/pkg/common"
 	"github.com/jesseduffield/lazygit/pkg/config"
 	"github.com/jesseduffield/lazygit/pkg/utils"
@@ -80,10 +79,6 @@ func FileType(path string) string {
 
 func (c *OSCommand) OpenFile(filename string) error {
 	commandTemplate := c.UserConfig().OS.Open
-	if commandTemplate == "" {
-		// Legacy support
-		commandTemplate = c.UserConfig().OS.OpenCommand
-	}
 	if commandTemplate == "" {
 		commandTemplate = config.GetPlatformDefaultConfig().Open
 	}
@@ -96,10 +91,6 @@ func (c *OSCommand) OpenFile(filename string) error {
 
 func (c *OSCommand) OpenLink(link string) error {
 	commandTemplate := c.UserConfig().OS.OpenLink
-	if commandTemplate == "" {
-		// Legacy support
-		commandTemplate = c.UserConfig().OS.OpenLinkCommand
-	}
 	if commandTemplate == "" {
 		commandTemplate = config.GetPlatformDefaultConfig().OpenLink
 	}
@@ -222,7 +213,7 @@ func (c *OSCommand) PipeCommands(cmdObjs ...*CmdObj) error {
 
 	c.LogCommand(logCmdStr, true)
 
-	for i := 0; i < len(cmds)-1; i++ {
+	for i := range len(cmds) - 1 {
 		stdout, err := cmds[i].StdoutPipe()
 		if err != nil {
 			return err
@@ -272,18 +263,8 @@ func (c *OSCommand) PipeCommands(cmdObjs ...*CmdObj) error {
 	return nil
 }
 
-// Kill kills a process. If the process has Setpgid == true, then we have anticipated that it might spawn its own child processes, so we've given it a process group ID (PGID) equal to its process id (PID) and given its child processes will inherit the PGID, we can kill that group, rather than killing the process itself.
-func Kill(cmd *exec.Cmd) error {
-	return kill.Kill(cmd)
-}
-
-// PrepareForChildren sets Setpgid to true on the cmd, so that when we run it as a subprocess, we can kill its group rather than the process itself. This is because some commands, like `docker-compose logs` spawn multiple children processes, and killing the parent process isn't sufficient for killing those child processes. We set the group id here, and then in subprocess.go we check if the group id is set and if so, we kill the whole group rather than just the one process.
-func PrepareForChildren(cmd *exec.Cmd) {
-	kill.PrepareForChildren(cmd)
-}
-
 func (c *OSCommand) CopyToClipboard(str string) error {
-	escaped := strings.Replace(str, "\n", "\\n", -1)
+	escaped := strings.ReplaceAll(str, "\n", "\\n")
 	truncated := utils.TruncateWithEllipsis(escaped, 40)
 
 	msg := utils.ResolvePlaceholderString(
