@@ -18,7 +18,7 @@ import (
 )
 
 type FilesController struct {
-	baseController // nolint: unused
+	baseController
 	*ListControllerTrait[*filetree.FileNode]
 	c *ControllerCommon
 }
@@ -208,36 +208,12 @@ func (self *FilesController) GetKeybindings(opts types.KeybindingsOpts) []*types
 
 func (self *FilesController) GetMouseKeybindings(opts types.KeybindingsOpts) []*gocui.ViewMouseBinding {
 	return []*gocui.ViewMouseBinding{
-		{
-			ViewName:    "main",
-			Key:         gocui.MouseLeft,
-			Handler:     self.onClickMain,
-			FocusedView: self.context().GetViewName(),
-		},
-		{
-			ViewName:    "patchBuilding",
-			Key:         gocui.MouseLeft,
-			Handler:     self.onClickMain,
-			FocusedView: self.context().GetViewName(),
-		},
 		{
 			ViewName:    "mergeConflicts",
 			Key:         gocui.MouseLeft,
 			Handler:     self.onClickMain,
 			FocusedView: self.context().GetViewName(),
 		},
-		{
-			ViewName:    "secondary",
-			Key:         gocui.MouseLeft,
-			Handler:     self.onClickSecondary,
-			FocusedView: self.context().GetViewName(),
-		},
-		{
-			ViewName:    "patchBuildingSecondary",
-			Key:         gocui.MouseLeft,
-			Handler:     self.onClickSecondary,
-			FocusedView: self.context().GetViewName(),
-		},
 	}
 }
 
@@ -286,15 +262,14 @@ func (self *FilesController) GetOnRenderToMain() func() {
 				}
 				if node.File.ShortStatus == "DU" || node.File.ShortStatus == "UD" {
 					cmdObj := self.c.Git().Diff.DiffCmdObj([]string{"--base", "--", node.GetPath()})
-					task := types.NewRunPtyTask(cmdObj.GetCmd())
-					task.Prefix = message + "\n\n"
+					prefix := message + "\n\n"
 					if node.File.ShortStatus == "DU" {
-						task.Prefix += self.c.Tr.MergeConflictIncomingDiff
+						prefix += self.c.Tr.MergeConflictIncomingDiff
 					} else {
-						task.Prefix += self.c.Tr.MergeConflictCurrentDiff
+						prefix += self.c.Tr.MergeConflictCurrentDiff
 					}
-					task.Prefix += "\n\n"
-					opts.Main.Task = task
+					prefix += "\n\n"
+					opts.Main.Task = types.NewRunPtyTaskWithPrefix(cmdObj.GetCmd(), prefix)
 				} else {
 					opts.Main.Task = types.NewRenderStringTask(message)
 				}
@@ -304,11 +279,6 @@ func (self *FilesController) GetOnRenderToMain() func() {
 
 			self.c.Helpers().MergeConflicts.ResetMergeState()
 
-			pair := self.c.MainViewPairs().Normal
-			if node.File != nil {
-				pair = self.c.MainViewPairs().Staging
-			}
-
 			split := self.c.UserConfig().Gui.SplitDiff == "always" || (node.GetHasUnstagedChanges() && node.GetHasStagedChanges())
 			mainShowsStaged := !split && node.GetHasStagedChanges()
 
@@ -318,7 +288,7 @@ func (self *FilesController) GetOnRenderToMain() func() {
 				title = self.c.Tr.StagedChanges
 			}
 			refreshOpts := types.RefreshMainOpts{
-				Pair: pair,
+				Pair: self.c.MainViewPairs().Normal,
 				Main: &types.ViewUpdateOpts{
 					Task:     types.NewRunPtyTask(cmdObj.GetCmd()),
 					SubTitle: self.c.Helpers().Diff.IgnoringWhitespaceSubTitle(),
@@ -352,6 +322,16 @@ func (self *FilesController) GetOnClick() func() error {
 	})
 }
 
+func (self *FilesController) GetOnClickFocusedMainView() func(mainViewName string, clickedLineIdx int) error {
+	return func(mainViewName string, clickedLineIdx int) error {
+		node := self.getSelectedItem()
+		if node != nil && node.File != nil {
+			return self.EnterFile(types.OnFocusOpts{ClickedWindowName: mainViewName, ClickedViewLineIdx: clickedLineIdx})
+		}
+		return nil
+	}
+}
+
 // if we are dealing with a status for which there is no key in this map,
 // then we won't optimistically render: we'll just let `git status` tell
 // us what the new status is.
@@ -505,9 +485,7 @@ func (self *FilesController) press(nodes []*filetree.FileNode) error {
 		return err
 	}
 
-	if err := self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}, Mode: types.ASYNC}); err != nil {
-		return err
-	}
+	self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}, Mode: types.ASYNC})
 
 	self.context().HandleFocus(types.OnFocusOpts{})
 	return nil
@@ -574,7 +552,10 @@ func (self *FilesController) EnterFile(opts types.OnFocusOpts) error {
 		return self.handleNonInlineConflict(file)
 	}
 
-	self.c.Context().Push(self.c.Contexts().Staging, opts)
+	context := lo.Ternary(opts.ClickedWindowName == "secondary", self.c.Contexts().StagingSecondary, self.c.Contexts().Staging)
+	self.c.Context().Push(context, opts)
+	self.c.Helpers().PatchBuilding.ShowHunkStagingHint()
+
 	return nil
 }
 
@@ -584,7 +565,8 @@ func (self *FilesController) handleNonInlineConflict(file *models.File) error {
 		if err := command(file.GetPath()); err != nil {
 			return err
 		}
-		return self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}})
+		self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}})
+		return nil
 	}
 	keepItem := &types.MenuItem{
 		Label: self.c.Tr.MergeConflictKeepFile,
@@ -629,9 +611,7 @@ func (self *FilesController) toggleStagedAll() error {
 		return err
 	}
 
-	if err := self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}, Mode: types.ASYNC}); err != nil {
-		return err
-	}
+	self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}, Mode: types.ASYNC})
 
 	self.context().HandleFocus(types.OnFocusOpts{})
 	return nil
@@ -656,7 +636,8 @@ func (self *FilesController) toggleStagedAllWithLock() error {
 			return err
 		}
 
-		if err := self.c.Git().WorkingTree.StageAll(); err != nil {
+		onlyTrackedFiles := self.context().GetFilter() == filetree.DisplayTracked
+		if err := self.c.Git().WorkingTree.StageAll(onlyTrackedFiles); err != nil {
 			return err
 		}
 	} else {
@@ -701,7 +682,8 @@ func (self *FilesController) ignoreOrExcludeTracked(node *filetree.FileNode, trA
 		return err
 	}
 
-	return self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}})
+	self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}})
+	return nil
 }
 
 func (self *FilesController) ignoreOrExcludeUntracked(node *filetree.FileNode, trAction string, f func(string) error) error {
@@ -711,7 +693,8 @@ func (self *FilesController) ignoreOrExcludeUntracked(node *filetree.FileNode, t
 		return err
 	}
 
-	return self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}})
+	self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}})
+	return nil
 }
 
 func (self *FilesController) ignoreOrExcludeFile(node *filetree.FileNode, trText string, trPrompt string, trAction string, f func(string) error) error {
@@ -773,7 +756,8 @@ func (self *FilesController) ignoreOrExcludeMenu(node *filetree.FileNode) error
 }
 
 func (self *FilesController) refresh() error {
-	return self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}})
+	self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}})
+	return nil
 }
 
 func (self *FilesController) handleAmendCommitPress() error {
@@ -813,28 +797,28 @@ func (self *FilesController) handleAmendCommitPress() error {
 				},
 			},
 		})
-	} else {
-		self.c.Confirm(types.ConfirmOpts{
+	}
+
+	return self.c.ConfirmIf(!self.c.UserConfig().Gui.SkipAmendWarning,
+		types.ConfirmOpts{
 			Title:  self.c.Tr.AmendLastCommitTitle,
 			Prompt: self.c.Tr.SureToAmend,
 			HandleConfirm: func() error {
 				return doAmend()
 			},
-		})
-	}
-
-	return nil
+		},
+	)
 }
 
 func (self *FilesController) isResolvingConflicts() bool {
 	commits := self.c.Model().Commits
 	for _, c := range commits {
-		if c.Status != models.StatusRebasing {
-			break
-		}
-		if c.Action == models.ActionConflict {
+		if c.Status == models.StatusConflicted {
 			return true
 		}
+		if !c.IsTODO() {
+			break
+		}
 	}
 	return false
 }
@@ -916,12 +900,11 @@ func (self *FilesController) setStatusFiltering(filter filetree.FileTreeDisplayF
 	// Whenever we switch between untracked and other filters, we need to refresh the files view
 	// because the untracked files filter applies when running `git status`.
 	if previousFilter != filter && (previousFilter == filetree.DisplayUntracked || filter == filetree.DisplayUntracked) {
-		return self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}, Mode: types.ASYNC})
+		self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES}, Mode: types.ASYNC})
 	} else {
 		self.c.PostRefreshUpdate(self.context())
-
-		return nil
 	}
+	return nil
 }
 
 func (self *FilesController) edit(nodes []*filetree.FileNode) error {
@@ -1162,7 +1145,7 @@ func (self *FilesController) stash() error {
 }
 
 func (self *FilesController) createResetToUpstreamMenu() error {
-	return self.c.Helpers().Refs.CreateGitResetMenu("@{upstream}")
+	return self.c.Helpers().Refs.CreateGitResetMenu("@{upstream}", "@{upstream}")
 }
 
 func (self *FilesController) handleToggleDirCollapsed() error {
@@ -1194,7 +1177,8 @@ func (self *FilesController) handleStashSave(stashFunc func(message string) erro
 			if err := stashFunc(stashComment); err != nil {
 				return err
 			}
-			return self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.STASH, types.FILES}})
+			self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.STASH, types.FILES}})
+			return nil
 		},
 	})
 
@@ -1205,32 +1189,25 @@ func (self *FilesController) onClickMain(opts gocui.ViewMouseBindingOpts) error
 	return self.EnterFile(types.OnFocusOpts{ClickedWindowName: "main", ClickedViewLineIdx: opts.Y})
 }
 
-func (self *FilesController) onClickSecondary(opts gocui.ViewMouseBindingOpts) error {
-	return self.EnterFile(types.OnFocusOpts{ClickedWindowName: "secondary", ClickedViewLineIdx: opts.Y})
-}
-
 func (self *FilesController) fetch() error {
 	return self.c.WithWaitingStatus(self.c.Tr.FetchingStatus, func(task gocui.Task) error {
-		if err := self.fetchAux(task); err != nil {
-			return err
+		self.c.LogAction("Fetch")
+		err := self.c.Git().Sync.Fetch(task)
+
+		if err != nil && strings.Contains(err.Error(), "exit status 128") {
+			return errors.New(self.c.Tr.PassUnameWrong)
 		}
-		return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
+
+		self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.BRANCHES, types.COMMITS, types.REMOTES, types.TAGS}, Mode: types.SYNC})
+
+		if err == nil {
+			err = self.c.Helpers().BranchesHelper.AutoForwardBranches()
+		}
+
+		return err
 	})
 }
 
-func (self *FilesController) fetchAux(task gocui.Task) (err error) {
-	self.c.LogAction("Fetch")
-	err = self.c.Git().Sync.Fetch(task)
-
-	if err != nil && strings.Contains(err.Error(), "exit status 128") {
-		return errors.New(self.c.Tr.PassUnameWrong)
-	}
-
-	_ = self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.BRANCHES, types.COMMITS, types.REMOTES, types.TAGS}, Mode: types.ASYNC})
-
-	return err
-}
-
 // Couldn't think of a better term than 'normalised'. Alas.
 // The idea is that when you select a range of nodes, you will often have both
 // a node and its parent node selected. If we are trying to discard changes to the
@@ -1346,7 +1323,8 @@ func (self *FilesController) remove(selectedNodes []*filetree.FileNode) error {
 				}
 			}
 
-			return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES, types.WORKTREES}})
+			self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES, types.WORKTREES}})
+			return nil
 		},
 		Key: self.c.KeybindingsOpts().GetKey(self.c.UserConfig().Keybinding.Files.ConfirmDiscard),
 		Tooltip: utils.ResolvePlaceholderString(
@@ -1372,7 +1350,8 @@ func (self *FilesController) remove(selectedNodes []*filetree.FileNode) error {
 				}
 			}
 
-			return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES, types.WORKTREES}})
+			self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES, types.WORKTREES}})
+			return nil
 		},
 		Key: 'u',
 		Tooltip: utils.ResolvePlaceholderString(
@@ -1413,7 +1392,8 @@ func (self *FilesController) ResetSubmodule(submodule *models.SubmoduleConfig) e
 			return err
 		}
 
-		return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES, types.SUBMODULES}})
+		self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES, types.SUBMODULES}})
+		return nil
 	})
 }
 
