@@ -167,9 +167,9 @@ func (self *ModeHelper) ClearFiltering() error {
 		self.c.State().GetRepoState().SetScreenMode(types.SCREEN_NORMAL)
 	}
 
-	return self.c.Refresh(types.RefreshOptions{
-		Scope: []types.RefreshableView{types.COMMITS},
-		Then: func() error {
+	self.c.Refresh(types.RefreshOptions{
+		Scope: ScopesToRefreshWhenFilteringModeChanges(),
+		Then: func() {
 			// Find the commit that was last selected in filtering mode, and select it again after refreshing
 			if !self.c.Contexts().LocalCommits.SelectCommitByHash(selectedCommitHash) {
 				// If we couldn't find it (either because no commit was selected
@@ -178,9 +178,22 @@ func (self *ModeHelper) ClearFiltering() error {
 				// before we entered filtering
 				self.c.Contexts().LocalCommits.SelectCommitByHash(self.c.Modes().Filtering.GetSelectedCommitHash())
 			}
-			return nil
+
+			self.c.PostRefreshUpdate(self.c.Contexts().LocalCommits)
 		},
 	})
+	return nil
+}
+
+// Stashes really only need to be refreshed when filtering by path, not by author, but it's too much
+// work to distinguish this, and refreshing stashes is fast, so we don't bother
+func ScopesToRefreshWhenFilteringModeChanges() []types.RefreshableView {
+	return []types.RefreshableView{
+		types.COMMITS,
+		types.SUB_COMMITS,
+		types.REFLOG,
+		types.STASH,
+	}
 }
 
 func (self *ModeHelper) SetSuppressRebasingMode(value bool) {
