@@ -9,6 +9,7 @@ import (
 	"time"
 
 	"github.com/jesseduffield/gocui"
+	"github.com/jesseduffield/lazygit/pkg/gui/controllers/helpers"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 )
@@ -30,18 +31,27 @@ func (self *FilesController) createResetMenu() error {
 				red.Sprint(nukeStr),
 			},
 			OnPress: func() error {
-				self.c.LogAction(self.c.Tr.Actions.NukeWorkingTree)
-				if err := self.c.Git().WorkingTree.ResetAndClean(); err != nil {
-					return err
-				}
+				self.c.Confirm(
+					types.ConfirmOpts{
+						Title:  self.c.Tr.Actions.NukeWorkingTree,
+						Prompt: self.c.Tr.NukeTreeConfirmation,
+						HandleConfirm: func() error {
+							self.c.LogAction(self.c.Tr.Actions.NukeWorkingTree)
+							if err := self.c.Git().WorkingTree.ResetAndClean(); err != nil {
+								return err
+							}
 
-				if self.c.UserConfig().Gui.AnimateExplosion {
-					self.animateExplosion()
-				}
+							if self.c.UserConfig().Gui.AnimateExplosion {
+								self.animateExplosion()
+							}
 
-				return self.c.Refresh(
-					types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES}},
-				)
+							self.c.Refresh(
+								types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES}},
+							)
+							return nil
+						},
+					})
+				return nil
 			},
 			Key:     'x',
 			Tooltip: self.c.Tr.NukeDescription,
@@ -57,9 +67,10 @@ func (self *FilesController) createResetMenu() error {
 					return err
 				}
 
-				return self.c.Refresh(
+				self.c.Refresh(
 					types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES}},
 				)
+				return nil
 			},
 			Key: 'u',
 		},
@@ -74,9 +85,10 @@ func (self *FilesController) createResetMenu() error {
 					return err
 				}
 
-				return self.c.Refresh(
+				self.c.Refresh(
 					types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES}},
 				)
+				return nil
 			},
 			Key: 'c',
 		},
@@ -98,9 +110,10 @@ func (self *FilesController) createResetMenu() error {
 					return err
 				}
 
-				return self.c.Refresh(
+				self.c.Refresh(
 					types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES}},
 				)
+				return nil
 			},
 			Key: 'S',
 		},
@@ -115,9 +128,10 @@ func (self *FilesController) createResetMenu() error {
 					return err
 				}
 
-				return self.c.Refresh(
+				self.c.Refresh(
 					types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES}},
 				)
+				return nil
 			},
 			Key: 's',
 		},
@@ -132,9 +146,10 @@ func (self *FilesController) createResetMenu() error {
 					return err
 				}
 
-				return self.c.Refresh(
+				self.c.Refresh(
 					types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES}},
 				)
+				return nil
 			},
 			Key: 'm',
 		},
@@ -144,14 +159,22 @@ func (self *FilesController) createResetMenu() error {
 				red.Sprint("git reset --hard HEAD"),
 			},
 			OnPress: func() error {
-				self.c.LogAction(self.c.Tr.Actions.HardReset)
-				if err := self.c.Git().WorkingTree.ResetHard("HEAD"); err != nil {
-					return err
-				}
+				return self.c.ConfirmIf(helpers.IsWorkingTreeDirty(self.c.Model().Files),
+					types.ConfirmOpts{
+						Title:  self.c.Tr.Actions.HardReset,
+						Prompt: self.c.Tr.ResetHardConfirmation,
+						HandleConfirm: func() error {
+							self.c.LogAction(self.c.Tr.Actions.HardReset)
+							if err := self.c.Git().WorkingTree.ResetHard("HEAD"); err != nil {
+								return err
+							}
 
-				return self.c.Refresh(
-					types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES}},
-				)
+							self.c.Refresh(
+								types.RefreshOptions{Mode: types.ASYNC, Scope: []types.RefreshableView{types.FILES}},
+							)
+							return nil
+						},
+					})
 			},
 			Key: 'h',
 		},
@@ -162,17 +185,14 @@ func (self *FilesController) createResetMenu() error {
 
 func (self *FilesController) animateExplosion() {
 	self.Explode(self.c.Views().Files, func() {
-		err := self.c.PostRefreshUpdate(self.c.Contexts().Files)
-		if err != nil {
-			self.c.Log.Error(err)
-		}
+		self.c.PostRefreshUpdate(self.c.Contexts().Files)
 	})
 }
 
 // Animates an explosion within the view by drawing a bunch of flamey characters
 func (self *FilesController) Explode(v *gocui.View, onDone func()) {
 	width := v.InnerWidth()
-	height := v.InnerHeight() + 1
+	height := v.InnerHeight()
 	styles := []style.TextStyle{
 		style.FgLightWhite.SetBold(),
 		style.FgYellow.SetBold(),
@@ -183,7 +203,7 @@ func (self *FilesController) Explode(v *gocui.View, onDone func()) {
 
 	self.c.OnWorker(func(_ gocui.Task) error {
 		max := 25
-		for i := 0; i < max; i++ {
+		for i := range max {
 			image := getExplodeImage(width, height, i, max)
 			style := styles[(i*len(styles)/max)%len(styles)]
 			coloredImage := style.Sprint(image)
@@ -232,8 +252,8 @@ func getExplodeImage(width int, height int, frame int, max int) string {
 		innerRadius = (progress - 0.5) * 2 * maxRadius
 	}
 
-	for y := 0; y < height; y++ {
-		for x := 0; x < width; x++ {
+	for y := range height {
+		for x := range width {
 			// calculate distance from center, scale x by 2 to compensate for character aspect ratio
 			distance := math.Hypot(float64(x-centerX), float64(y-centerY)*2)
 
