@@ -88,12 +88,15 @@ type IBaseContext interface {
 
 	AddKeybindingsFn(KeybindingsFn)
 	AddMouseKeybindingsFn(MouseKeybindingsFn)
-	ClearAllBindingsFn()
+	ClearAllAttachedControllerFunctions()
 
 	// This is a bit of a hack at the moment: we currently only set an onclick function so that
 	// our list controller can come along and wrap it in a list-specific click handler.
 	// We'll need to think of a better way to do this.
 	AddOnClickFn(func() error)
+	// Likewise for the focused main view: we need this to communicate between a
+	// side panel controller and the focused main view controller.
+	AddOnClickFocusedMainViewFn(func(mainViewName string, clickedLineIdx int) error)
 
 	AddOnRenderToMainFn(func())
 	AddOnFocusFn(func(OnFocusOpts))
@@ -105,6 +108,7 @@ type Context interface {
 
 	HandleFocus(opts OnFocusOpts)
 	HandleFocusLost(opts OnFocusLostOpts)
+	FocusLine()
 	HandleRender()
 	HandleRenderToMain()
 }
@@ -173,10 +177,11 @@ type IListContext interface {
 	ViewIndexToModelIndex(int) int
 	ModelIndexToViewIndex(int) int
 
-	FocusLine()
 	IsListContext() // used for type switch
 	RangeSelectEnabled() bool
 	RenderOnlyVisibleLines() bool
+
+	IndexForGotoBottom() int
 }
 
 type IPatchExplorerContext interface {
@@ -187,7 +192,6 @@ type IPatchExplorerContext interface {
 	GetIncludedLineIndices() []int
 	RenderAndFocus()
 	Render()
-	Focus()
 	GetContentToRender() string
 	NavigateTo(selectedLineIdx int)
 	GetMutex() *deadlock.Mutex
@@ -240,14 +244,16 @@ type HasKeybindings interface {
 	GetKeybindings(opts KeybindingsOpts) []*Binding
 	GetMouseKeybindings(opts KeybindingsOpts) []*gocui.ViewMouseBinding
 	GetOnClick() func() error
-	GetOnRenderToMain() func()
-	GetOnFocus() func(OnFocusOpts)
-	GetOnFocusLost() func(OnFocusLostOpts)
+	GetOnClickFocusedMainView() func(mainViewName string, clickedLineIdx int) error
 }
 
 type IController interface {
 	HasKeybindings
 	Context() Context
+
+	GetOnRenderToMain() func()
+	GetOnFocus() func(OnFocusOpts)
+	GetOnFocusLost() func(OnFocusLostOpts)
 }
 
 type IList interface {
@@ -294,6 +300,7 @@ type IContextMgr interface {
 	CurrentStatic() Context
 	CurrentSide() Context
 	CurrentPopup() []Context
+	NextInStack(context Context) Context
 	IsCurrent(c Context) bool
 	IsCurrentOrParent(c Context) bool
 	ForEach(func(Context))
